@@ -49,6 +49,11 @@ class Enviar(object):
             return Decimal("0.00")
         return valor_desconto
 
+    @property
+    def valor_subtotal(self):
+        valor_subtotal = self.pedido.valor_subtotal or Decimal("0.00")
+        return valor_subtotal - self.valor_desconto
+
 
 class EnviarPedido(Plugavel):
     def __init__(self, pedido_numero, dados, conta_id, configuracao_pagamento):
