@@ -63,9 +63,7 @@ class Parametros(object):
                     conteudo = getattr(conteudo, atributo)
             except AttributeError:
                 raise ParametroInstalacaoInvalido(u"O atributo {} definido em pagador.settings.MODULO_PARAMETROS_INSTALACAO não é membro do classe {}.".format(parametros["atributo"], parametros["classe"]))
-            if conteudo is None:
-                self.monta_paramentros(id=1)
-            else:
+            if self.meio_pagamento in conteudo:
                 #FIXME: só funciona se o parâmetro for um dicionário.
                 for chave in self.chaves:
                     if parametros["tipo_atributo"] == "dict":
@@ -73,6 +71,8 @@ class Parametros(object):
                         if chave in conteudo[self.meio_pagamento]:
                             valor = conteudo[self.meio_pagamento][chave]
                         setattr(self, chave, valor)
+            else:
+                self.monta_paramentros(id=1)
         except KeyError:
             raise ParametroInstalacaoInvalido(u"O atributo ou o tipo do atributo não foi encontrado nas configurações. Você esqueceu de inclui-lo em pagador.settings.MODULO_PARAMETROS_INSTALACAO?")
 
